@@ -144,7 +144,7 @@ void HtmlListenerImpl::openSpan(const WPXPropertyList &propList)
 
 		printf("<span style=\"");
 		if (propList["style:font-name"])
-			printf("font-family: \'%s\'\;", propList["style:font-name"]->getStr().cstr());
+			printf("font-family: \'%s\';", propList["style:font-name"]->getStr().cstr());
 		if (propList["fo:font-size"])
 			printf("font-size: %s;", propList["fo:font-size"]->getStr().cstr());
 		if (propList["fo:font-weight"])
