@@ -32,6 +32,9 @@ extern int WP6_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16];
 /* standard sizes */
 #define WP6_NUM_LIST_LEVELS 8
 
+/* Misc. Junk */
+#define WP6_NUM_EXTRA_WPU 19
+
 /* header defines */
 #define WP6_HEADER_DOCUMENT_SIZE_OFFSET 20
 #define WP6_HEADER_INDEX_HEADER_POINTER_OFFSET 14
@@ -103,7 +106,7 @@ extern int WP6_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16];
 #define WP6_TOP_DELETABLE_SOFT_EOL_AT_EOC_AT_EOP 0xBA
 #define WP6_TOP_DELETABLE_SOFT_EOL_AT_EOC 0xBB
 #define WP6_TOP_DELETABLE_SOFT_EOL 0xBC
-/*
+
 #define WP6_TOP_TABLE_OFF_AT_EOC_AT_EOP 0xBD
 #define WP6_TOP_TABLE_OFF_AT_EOC 0xBE
 #define WP6_TOP_TABLE_OFF 0xBF
@@ -114,7 +117,7 @@ extern int WP6_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16];
 #define WP6_TOP_TABLE_ROW_AT_EOC 0xC4
 #define WP6_TOP_TABLE_ROW 0xC5
 #define WP6_TOP_TABLE_CELL 0xC6
-*/
+
 #define WP6_TOP_HARD_EOP 0xC7
 #define WP6_TOP_HARD_EOC_AT_EOP 0xC8
 #define WP6_TOP_HARD_EOC 0xC9
@@ -149,11 +152,14 @@ extern int WP6_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16];
 #define WP6_TOP_UNDO_GROUP 0xF1
 #define WP6_TOP_ATTRIBUTE_ON 0xF2
 #define WP6_TOP_ATTRIBUTE_OFF 0xF3
+#define WP6_TOP_HIGHLIGHT_ON 0xFB
+#define WP6_TOP_HIGHLIGHT_OFF 0xFC
 
 /* Page Group */
 #define WP6_PAGE_GROUP_TOP_MARGIN_SET 0x00
 #define WP6_PAGE_GROUP_BOTTOM_MARGIN_SET 0x01
 #define WP6_PAGE_GROUP_SUPPRESS_PAGE_CHARACTERISTICS 0x02
+#define WP6_PAGE_GROUP_FORM 0x11
 
 // breaking style here so our symbols aren't (as) ridiculously long
 #define WP6_PAGE_GROUP_SUPPRESS_PAGE_NUMBER 1
@@ -235,7 +241,10 @@ extern int WP6_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16];
 
 /* Paragraph Group */
 #define WP6_PARAGRAPH_GROUP_LINE_SPACING 0x01
+#define WP6_PARAGRAPH_GROUP_TAB_SET 0x04
 #define WP6_PARAGRAPH_GROUP_JUSTIFICATION 0x05
+#define WP6_PARAGRAPH_GROUP_SPACING_AFTER_PARAGRAPH 0x0A
+#define WP6_PARAGRAPH_GROUP_INDENT_FIRST_LINE_OF_PARAGRAPH 0x0B
 #define WP6_PARAGRAPH_GROUP_LEFT_MARGIN_ADJUSTMENT 0x0C
 #define WP6_PARAGRAPH_GROUP_RIGHT_MARGIN_ADJUSTMENT 0x0D
 #define WP6_PARAGRAPH_GROUP_OUTLINE_DEFINE 0x0E
@@ -264,8 +273,12 @@ extern int WP6_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16];
 #define WP6_DISPLAY_NUMBER_REFERENCE_GROUP_ENDNOTE_NUMBER_OFF 0x11
 
 /* Character Group */
+#define WP6_CHARACTER_GROUP_SET_ALIGNMENT_CHARACTER 0x00
+#define WP6_CHARACTER_GROUP_COLOR 0x18
+#define WP6_CHARACTER_GROUP_CHARACTER_SHADING_CHANGE 0x19
 #define WP6_CHARACTER_GROUP_FONT_FACE_CHANGE 0x1A
 #define WP6_CHARACTER_GROUP_FONT_SIZE_CHANGE 0x1B
+#define WP6_CHARACTER_GROUP_SET_DOT_LEADER_CHARACTERS 0x1E
 #define WP6_CHARACTER_GROUP_PARAGRAPH_NUMBER_ON 0x32
 #define WP6_CHARACTER_GROUP_PARAGRAPH_NUMBER_OFF 0x33
 #define WP6_CHARACTER_GROUP_TABLE_DEFINITION_ON 0x2A
@@ -300,6 +313,11 @@ extern int WP6_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16];
 #define WP6_COLUMN_TYPE_PARALLEL_PROTECT 0x03
 
 /* Attribute Group */
+#define WP6_ATTRIBUTE_EXTRA_LARGE 0
+#define WP6_ATTRIBUTE_VERY_LARGE 1
+#define WP6_ATTRIBUTE_LARGE 2
+#define WP6_ATTRIBUTE_SMALL_PRINT 3
+#define WP6_ATTRIBUTE_FINE_PRINT 4
 #define WP6_ATTRIBUTE_SUPERSCRIPT 5
 #define WP6_ATTRIBUTE_SUBSCRIPT 6
 #define WP6_ATTRIBUTE_OUTLINE 7
@@ -315,11 +333,19 @@ extern int WP6_FIXED_LENGTH_FUNCTION_GROUP_SIZE[16];
 
 /* Tab Group */
 // these elements are defined in terms of bits 3-8 of the tab group
+#define WP6_TAB_GROUP_BACK_TAB 0x00
+#define WP6_TAB_GROUP_TABLE_TAB 0x01
+#define WP6_TAB_GROUP_LEFT_TAB 0x02
+#define WP6_TAB_GROUP_BAR_TAB 0x04
+#define WP6_TAB_GROUP_LEFT_INDENT 0x06
+#define WP6_TAB_GROUP_LEFT_RIGHT_INDENT 0x07
 #define WP6_TAB_GROUP_CENTER_ON_MARGINS 0x08
 #define WP6_TAB_GROUP_CENTER_ON_CURRENT_POSITION 0x09
 #define WP6_TAB_GROUP_CENTER_TAB 0x0A
 #define WP6_TAB_GROUP_FLUSH_RIGHT 0x10
 #define WP6_TAB_GROUP_RIGHT_TAB 0x12
+#define WP6_TAB_GROUP_DECIMAL_TAB 0x1A
+
 
 /* Extended Character */
 #define WP6_MULTINATIONAL_CHARACTER_SET 1
