@@ -137,12 +137,14 @@ void WP6HLStylesListener::headerFooterGroup(const uint8_t headerFooterType, cons
 	{			
 		WPD_DEBUG_MSG(("WordPerfect: headerFooterGroup (headerFooterType: %i, occurenceBits: %i, textPID: %i)\n", 
 			       headerFooterType, occurenceBits, textPID));
+		bool tempCurrentPageHasContent = m_currentPageHasContent;
 		if (headerFooterType <= WP6_HEADER_FOOTER_GROUP_FOOTER_B) // ignore watermarks for now
 		{
 			WPXTableList tableList; 
 			m_currentPage->setHeaderFooter(headerFooterType, occurenceBits, textPID, tableList);
 			_handleSubDocument(textPID, true, tableList);
 		}
+		m_currentPageHasContent = tempCurrentPageHasContent;
 	}
 }
 
@@ -229,14 +231,18 @@ void WP6HLStylesListener::_handleSubDocument(uint16_t textPID, const bool isHead
 	// do want to capture whatever table-related information is within it..
 	if (!isUndoOn()) 
 	{
-		if (textPID)
+		std::set <int> oldTextPIDs;
+		oldTextPIDs = m_subDocumentTextPIDs;
+		// prevent entering in an endless loop		
+		if ((textPID) && (oldTextPIDs.find(textPID) == oldTextPIDs.end()))
 		{
+			m_subDocumentTextPIDs.insert(textPID);
 			if (isHeaderFooter) 
 			{
 				WPXTable * oldCurrentTable = m_currentTable;
 				WPXTableList oldTableList = m_tableList;
 				m_tableList = tableList;
-				
+
 				WP6LLListener::getPrefixDataPacket(textPID)->parse(this);
 
 				m_tableList = oldTableList;
@@ -246,6 +252,7 @@ void WP6HLStylesListener::_handleSubDocument(uint16_t textPID, const bool isHead
 			{
 				WP6LLListener::getPrefixDataPacket(textPID)->parse(this);
 			}
+			m_subDocumentTextPIDs = oldTextPIDs;
 
 		}
 	}
